==> aroundme_0_5_0.tar.tgz: aroundme_0_5_0/aroundme/language/1/barnraiser_01/search.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

// SECTION VARS
$lang['section_search'] = 						"search";

// HEADER VARS
$lang['hdr_search_results'] = 					"search results";
$lang['hdr_blogs'] = 							"blogs";
$lang['hdr_activities'] = 						"activities";
$lang['hdr_groups'] = 							"groups";
$lang['hdr_library_items'] = 					"library items";
$lang['hdr_polls'] = 							"polls";
$lang['hdr_subjects'] = 						"discussions";
$lang['hdr_tasks'] = 						"tasks";


//HREF VARS
$lang['href_advanced_search'] = 				"advanced search";

// TXT VARS
$lang['txt_search_basic_intro'] = 				"Search on articles within this network. You can search using 3 or more characters.";
$lang['txt_search'] = 							"search"; // breadcrumb

$lang['txt_genre'] = 							"genre";
$lang['txt_recommended_age'] = 					"recommended age";
$lang['txt_age_all'] = 							"all";
$lang['txt_age_from'] = 						"from";
$lang['txt_age_upto'] = 						"upto";
$lang['txt_votes'] = 							"votes";

//SEARCH RESULTS TEXT
$lang['txt_search_results'] = 					"search results for a search on SEARCHTEXT.";



?>

==> aroundme_0_6_2.tar.tgz: aroundme_0_6_2/aroundme/language/1/barnraiser_01/search.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'common.lang.php');

// HEADER VARS
$lang['hdr_search'] = 							"search";
$lang['hdr_search_results'] = 					"search results";
$lang['hdr_blogs'] = 							"blogs";
$lang['hdr_activities'] = 						"events";
$lang['hdr_library_items'] = 					"wiki pages";
$lang['hdr_polls'] = 							"polls";
$lang['hdr_subjects'] = 						"discussions";
$lang['hdr_tasks'] = 							"tasks";
$lang['hdr_groups'] = 							"groups";


// TXT VARS
$lang['txt_search_basic_intro'] = 				"Search on articles published to everyone within this network. You can search using 3 or more characters.";
$lang['txt_search'] = 							"search"; // breadcrumb
$lang['txt_recommended_age'] = 					"recommended age";
$lang['txt_age_all'] = 							"all";
$lang['txt_age_from'] = 						"from";
$lang['txt_age_upto'] = 						"upto";
$lang['txt_search_results'] = 					"search results for a search on SEARCHTEXT.";
$lang['txt_tag'] = 								"tags";

?>
